==> svix-1.15.0.tar.gz: svix-1.15.0/svix/internal/openapi_client/api/application/v1_application_get_stats.py <==
import datetime
import random
from http import HTTPStatus
from time import sleep
from typing import Any, Dict

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.application_stats import ApplicationStats
from ...models.http_error import HttpError
from ...models.http_validation_error import HTTPValidationError
from ...types import UNSET, Response

SLEEP_TIME = 0.05
NUM_RETRIES = 3


def _get_kwargs(
    app_id: str,
    *,
    client: AuthenticatedClient,
    since: datetime.datetime,
    until: datetime.datetime,
) -> Dict[str, Any]:
    url = "{}/api/v1/app/{app_id}/stats/".format(client.base_url, app_id=app_id)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    json_since = since.isoformat()

    params["since"] = json_since

    json_until = until.isoformat()

    params["until"] = json_until

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "follow_redirects": client.follow_redirects,
        "params": params,
    }


def _parse_response(*, client: Client, response: httpx.Response) -> ApplicationStats:
    if response.status_code == HTTPStatus.OK:
        response_200 = ApplicationStats.from_dict(response.json())

        return response_200
    if response.status_code == HTTPStatus.BAD_REQUEST:
        raise HttpError.init_exception(response.json(), response.status_code)
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        raise HttpError.init_exception(response.json(), response.status_code)
    if response.status_code == HTTPStatus.FORBIDDEN:
        raise HttpError.init_exception(response.json(), response.status_code)
    if response.status_code == HTTPStatus.NOT_FOUND:
        raise HttpError.init_exception(response.json(), response.status_code)
    if response.status_code == HTTPStatus.CONFLICT:
        raise HttpError.init_exception(response.json(), response.status_code)
    if response.status_code == HTTPStatus.UNPROCESSABLE_ENTITY:
        raise HTTPValidationError.init_exception(response.json(), response.status_code)
    if response.status_code == HTTPStatus.TOO_MANY_REQUESTS:
        raise HttpError.init_exception(response.json(), response.status_code)
    raise errors.UnexpectedStatus(response.status_code, response.content)


def _build_response(*, client: Client, response: httpx.Response) -> Response[ApplicationStats]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    app_id: str,
    *,
    client: AuthenticatedClient,
    since: datetime.datetime,
    until: datetime.datetime,
) -> Response[ApplicationStats]:
    """Get App Stats

     Get basic statistics for the application

    Args:
        app_id (str): The app's ID or UID Example: unique-app-identifier.
        since (datetime.datetime): Filter the range to data starting from this date
        until (datetime.datetime): Filter the range to data ending by this date

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[ApplicationStats]
    """

    kwargs = _get_kwargs(
        app_id=app_id,
        client=client,
        since=since,
        until=until,
    )

    kwargs["headers"] = {"svix-req-id": f"{random.getrandbits(32)}", **kwargs["headers"]}

    for retry_count in range(NUM_RETRIES):
        response = httpx.request(
            verify=client.verify_ssl,
            **kwargs,
        )
        if response.status_code >= 500:
            kwargs["headers"]["svix-retry-count"] = str(retry_count)
            sleep(SLEEP_TIME * (2**retry_count))
        else:
            break

    return _build_response(client=client, response=response)


def sync(
    app_id: str,
    *,
    client: AuthenticatedClient,
    since: datetime.datetime,
    until: datetime.datetime,
) -> ApplicationStats:
    """Get App Stats

     Get basic statistics for the application

    Args:
        app_id (str): The app's ID or UID Example: unique-app-identifier.
        since (datetime.datetime): Filter the range to data starting from this date
        until (datetime.datetime): Filter the range to data ending by this date

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        ApplicationStats
    """

    return sync_detailed(
        app_id=app_id,
        client=client,
        since=since,
        until=until,
    ).parsed


async def asyncio_detailed(
    app_id: str,
    *,
    client: AuthenticatedClient,
    since: datetime.datetime,
    until: datetime.datetime,
) -> Response[ApplicationStats]:
    """Get App Stats

     Get basic statistics for the application

    Args:
        app_id (str): The app's ID or UID Example: unique-app-identifier.
        since (datetime.datetime): Filter the range to data starting from this date
        until (datetime.datetime): Filter the range to data ending by this date

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[ApplicationStats]
    """

    kwargs = _get_kwargs(
        app_id=app_id,
        client=client,
        since=since,
        until=until,
    )

    kwargs["headers"] = {"svix-req-id": f"{random.getrandbits(32)}", **kwargs["headers"]}

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        for retry_count in range(NUM_RETRIES):
            response = await _client.request(**kwargs)
            if response.status_code >= 500:
                kwargs["headers"]["svix-retry-count"] = str(retry_count)
                sleep(SLEEP_TIME * (2**retry_count))
            else:
                break

    return _build_response(client=client, response=response)


async def asyncio(
    app_id: str,
    *,
    client: AuthenticatedClient,
    since: datetime.datetime,
    until: datetime.datetime,
) -> ApplicationStats:
    """Get App Stats

     Get basic statistics for the application

    Args:
        app_id (str): The app's ID or UID Example: unique-app-identifier.
        since (datetime.datetime): Filter the range to data starting from this date
        until (datetime.datetime): Filter the range to data ending by this date

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        ApplicationStats
    """

    return (
        await asyncio_detailed(
            app_id=app_id,
            client=client,
            since=since,
            until=until,
        )
    ).parsed

==> svix-1.20.0.tar.gz: svix-1.20.0/svix/internal/openapi_client/api/application/v1_application_get_stats.py <==
import asyncio
import datetime
import random
from http import HTTPStatus
from time import sleep
from typing import Any, Dict

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.application_stats import ApplicationStats
from ...models.http_error import HttpError
from ...models.http_validation_error import HTTPValidationError
from ...types import UNSET, Response


def _get_kwargs(
    app_id: str,
    *,
    client: AuthenticatedClient,
    since: datetime.datetime,
    until: datetime.datetime,
) -> Dict[str, Any]:
    url = "{}/api/v1/app/{app_id}/stats/".format(client.base_url, app_id=app_id)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    json_since = since.isoformat()

    params["since"] = json_since

    json_until = until.isoformat()

    params["until"] = json_until

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "follow_redirects": client.follow_redirects,
        "params": params,
    }


def _parse_response(*, client: Client, response: httpx.Response) -> ApplicationStats:
    if response.status_code == HTTPStatus.OK:
        response_200 = ApplicationStats.from_dict(response.json())

        return response_200
    if response.status_code == HTTPStatus.BAD_REQUEST:
        raise HttpError.init_exception(response.json(), response.status_code)
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        raise HttpError.init_exception(response.json(), response.status_code)
    if response.status_code == HTTPStatus.FORBIDDEN:
        raise HttpError.init_exception(response.json(), response.status_code)
    if response.status_code == HTTPStatus.NOT_FOUND:
        raise HttpError.init_exception(response.json(), response.status_code)
    if response.status_code == HTTPStatus.CONFLICT:
        raise HttpError.init_exception(response.json(), response.status_code)
    if response.status_code == HTTPStatus.UNPROCESSABLE_ENTITY:
        raise HTTPValidationError.init_exception(response.json(), response.status_code)
    if response.status_code == HTTPStatus.TOO_MANY_REQUESTS:
        raise HttpError.init_exception(response.json(), response.status_code)
    raise errors.UnexpectedStatus(response.status_code, response.content)


def _build_response(*, client: Client, response: httpx.Response) -> Response[ApplicationStats]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def request_sync_detailed(
    app_id: str,
    *,
    client: AuthenticatedClient,
    since: datetime.datetime,
    until: datetime.datetime,
) -> Response[ApplicationStats]:
    """Get App Stats

     Get basic statistics for the application

    Args:
        app_id (str): The app's ID or UID Example: unique-app-identifier.
        since (datetime.datetime): Filter the range to data starting from this date
        until (datetime.datetime): Filter the range to data ending by this date

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[ApplicationStats]
    """

    kwargs = _get_kwargs(
        app_id=app_id,
        client=client,
        since=since,
        until=until,
    )

    kwargs["headers"] = {"svix-req-id": f"{random.getrandbits(32)}", **kwargs["headers"]}

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )
    for retry_count, sleep_time in enumerate(client.retry_schedule):
        if response.status_code < 500:
            break

        sleep(sleep_time)
        kwargs["headers"]["svix-retry-count"] = str(retry_count)
        response = httpx.request(
            verify=client.verify_ssl,
            **kwargs,
        )

    return _build_response(client=client, response=response)


def request_sync(
    app_id: str,
    *,
    client: AuthenticatedClient,
    since: datetime.datetime,
    until: datetime.datetime,
) -> ApplicationStats:
    """Get App Stats

     Get basic statistics for the application

    Args:
        app_id (str): The app's ID or UID Example: unique-app-identifier.
        since (datetime.datetime): Filter the range to data starting from this date
        until (datetime.datetime): Filter the range to data ending by this date

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        ApplicationStats
    """

    return request_sync_detailed(
        app_id=app_id,
        client=client,
        since=since,
        until=until,
    ).parsed


async def request_asyncio_detailed(
    app_id: str,
    *,
    client: AuthenticatedClient,
    since: datetime.datetime,
    until: datetime.datetime,
) -> Response[ApplicationStats]:
    """Get App Stats

     Get basic statistics for the application

    Args:
        app_id (str): The app's ID or UID Example: unique-app-identifier.
        since (datetime.datetime): Filter the range to data starting from this date
        until (datetime.datetime): Filter the range to data ending by this date

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[ApplicationStats]
    """

    kwargs = _get_kwargs(
        app_id=app_id,
        client=client,
        since=since,
        until=until,
    )

    kwargs["headers"] = {"svix-req-id": f"{random.getrandbits(32)}", **kwargs["headers"]}

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

        for retry_count, sleep_time in enumerate(client.retry_schedule):
            if response.status_code < 500:
                break

            await asyncio.sleep(sleep_time)
            kwargs["headers"]["svix-retry-count"] = str(retry_count)
            response = await _client.request(**kwargs)

    return _build_response(client=client, response=response)


async def request_asyncio(
    app_id: str,
    *,
    client: AuthenticatedClient,
    since: datetime.datetime,
    until: datetime.datetime,
) -> ApplicationStats:
    """Get App Stats

     Get basic statistics for the application

    Args:
        app_id (str): The app's ID or UID Example: unique-app-identifier.
        since (datetime.datetime): Filter the range to data starting from this date
        until (datetime.datetime): Filter the range to data ending by this date

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        ApplicationStats
    """

    return (
        await request_asyncio_detailed(
            app_id=app_id,
            client=client,
            since=since,
            until=until,
        )
    ).parsed
